==> ejc-cost-api-3.0.0-20221020.104520-164-sources.jar: com/ejianc/business/cost/vo/CostStatisticVO.java <==
package com.ejianc.business.cost.vo;

import com.ejianc.business.budget.vo.BudgetProjectDetailProVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class CostStatisticVO {
    /**
     * 预算
     */
    private BigDecimal budgetTaxMny; // 预算总金额（含税）
    private BigDecimal indirectionTaxMny; // 间接费(含税)
    private BigDecimal laborTaxMny; // 人工费（含税）
    private BigDecimal materialTaxMny; // 材料费（含税）
    private BigDecimal majorTaxMny; // 专业费（含税）
    private BigDecimal mechanicalTaxMny; // 机械费(含税 )
    /**
     * 成本
     */
    private BigDecimal lastTaxMnyCost; // 累计成本金额
    private BigDecimal laborTaxMnyCost; // 人工费（含税）
    private BigDecimal majorTaxMnyCost; // 专业费（含税）
    private BigDecimal materialTaxMnyCost; // 材料费（含税）
    private BigDecimal mechanicalTaxMnyCost; // 机械费(含税)
    private BigDecimal indirectionTaxMnyCost; // 间接费用(含税)

    private List<CostStatisticDetailVO> detailList = new ArrayList<>(); // 项目预算清单明细

    public BigDecimal getBudgetTaxMny() {
        return budgetTaxMny;
    }

    public void setBudgetTaxMny(BigDecimal budgetTaxMny) {
        this.budgetTaxMny = budgetTaxMny;
    }

    public BigDecimal getIndirectionTaxMny() {
        return indirectionTaxMny;
    }

    public void setIndirectionTaxMny(BigDecimal indirectionTaxMny) {
        this.indirectionTaxMny = indirectionTaxMny;
    }

    public BigDecimal getLaborTaxMny() {
        return laborTaxMny;
    }

    public void setLaborTaxMny(BigDecimal laborTaxMny) {
        this.laborTaxMny = laborTaxMny;
    }

    public BigDecimal getMaterialTaxMny() {
        return materialTaxMny;
    }

    public void setMaterialTaxMny(BigDecimal materialTaxMny) {
        this.materialTaxMny = materialTaxMny;
    }

    public BigDecimal getMajorTaxMny() {
        return majorTaxMny;
    }

    public void setMajorTaxMny(BigDecimal majorTaxMny) {
        this.majorTaxMny = majorTaxMny;
    }

    public BigDecimal getMechanicalTaxMny() {
        return mechanicalTaxMny;
    }

    public void setMechanicalTaxMny(BigDecimal mechanicalTaxMny) {
        this.mechanicalTaxMny = mechanicalTaxMny;
    }

    public BigDecimal getLastTaxMnyCost() {
        return lastTaxMnyCost;
    }

    public void setLastTaxMnyCost(BigDecimal lastTaxMnyCost) {
        this.lastTaxMnyCost = lastTaxMnyCost;
    }

    public BigDecimal getLaborTaxMnyCost() {
        return laborTaxMnyCost;
    }

    public void setLaborTaxMnyCost(BigDecimal laborTaxMnyCost) {
        this.laborTaxMnyCost = laborTaxMnyCost;
    }

    public BigDecimal getMajorTaxMnyCost() {
        return majorTaxMnyCost;
    }

    public void setMajorTaxMnyCost(BigDecimal majorTaxMnyCost) {
        this.majorTaxMnyCost = majorTaxMnyCost;
    }

    public BigDecimal getMaterialTaxMnyCost() {
        return materialTaxMnyCost;
    }

    public void setMaterialTaxMnyCost(BigDecimal materialTaxMnyCost) {
        this.materialTaxMnyCost = materialTaxMnyCost;
    }

    public BigDecimal getMechanicalTaxMnyCost() {
        return mechanicalTaxMnyCost;
    }

    public void setMechanicalTaxMnyCost(BigDecimal mechanicalTaxMnyCost) {
        this.mechanicalTaxMnyCost = mechanicalTaxMnyCost;
    }

    public BigDecimal getIndirectionTaxMnyCost() {
        return indirectionTaxMnyCost;
    }

    public void setIndirectionTaxMnyCost(BigDecimal indirectionTaxMnyCost) {
        this.indirectionTaxMnyCost = indirectionTaxMnyCost;
    }

    public List<CostStatisticDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<CostStatisticDetailVO> detailList) {
        this.detailList = detailList;
    }
}

==> ejc-cost-api-3.0.0-20230110.054355-245-sources.jar: com/ejianc/business/cost/vo/CostStatisticVO.java <==
package com.ejianc.business.cost.vo;

import com.ejianc.business.budget.vo.BudgetProjectDetailProVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class CostStatisticVO {
    /**
     * 预算
     */
    private BigDecimal budgetTaxMny; // 预算总金额（含税）
    private BigDecimal indirectionTaxMny; // 间接费(含税)
    private BigDecimal laborTaxMny; // 人工费（含税）
    private BigDecimal materialTaxMny; // 材料费（含税）
    private BigDecimal majorTaxMny; // 专业费（含税）
    private BigDecimal mechanicalTaxMny; // 机械费(含税 )
    /**
     * 成本
     */
    private BigDecimal lastTaxMnyCost; // 累计成本金额
    private BigDecimal laborTaxMnyCost; // 人工费（含税）
    private BigDecimal majorTaxMnyCost; // 专业费（含税）
    private BigDecimal materialTaxMnyCost; // 材料费（含税）
    private BigDecimal mechanicalTaxMnyCost; // 机械费(含税)
    private BigDecimal indirectionTaxMnyCost; // 间接费用(含税)
    /**
     * 占比
     */
    private BigDecimal lastTaxMnyCostRatio; // 累计成本金额执行比例
    private BigDecimal laborTaxMnyCostRatio; // 人工费执行比例
    private BigDecimal majorTaxMnyCostRatio; // 专业费执行比例
    private BigDecimal materialTaxMnyCostRatio; // 材料费执行比例
    private BigDecimal mechanicalTaxMnyCostRatio; // 机械费执行比例
    private BigDecimal indirectionTaxMnyCostRatio; // 间接费用执行比例

    private List<CostStatisticDetailVO> detailList = new ArrayList<>(); // 项目预算清单明细

    public BigDecimal getBudgetTaxMny() {
        return budgetTaxMny;
    }

    public void setBudgetTaxMny(BigDecimal budgetTaxMny) {
        this.budgetTaxMny = budgetTaxMny;
    }

    public BigDecimal getIndirectionTaxMny() {
        return indirectionTaxMny;
    }

    public void setIndirectionTaxMny(BigDecimal indirectionTaxMny) {
        this.indirectionTaxMny = indirectionTaxMny;
    }

    public BigDecimal getLaborTaxMny() {
        return laborTaxMny;
    }

    public void setLaborTaxMny(BigDecimal laborTaxMny) {
        this.laborTaxMny = laborTaxMny;
    }

    public BigDecimal getMaterialTaxMny() {
        return materialTaxMny;
    }

    public void setMaterialTaxMny(BigDecimal materialTaxMny) {
        this.materialTaxMny = materialTaxMny;
    }

    public BigDecimal getMajorTaxMny() {
        return majorTaxMny;
    }

    public void setMajorTaxMny(BigDecimal majorTaxMny) {
        this.majorTaxMny = majorTaxMny;
    }

    public BigDecimal getMechanicalTaxMny() {
        return mechanicalTaxMny;
    }

    public void setMechanicalTaxMny(BigDecimal mechanicalTaxMny) {
        this.mechanicalTaxMny = mechanicalTaxMny;
    }

    public BigDecimal getLastTaxMnyCost() {
        return lastTaxMnyCost;
    }

    public void setLastTaxMnyCost(BigDecimal lastTaxMnyCost) {
        this.lastTaxMnyCost = lastTaxMnyCost;
    }

    public BigDecimal getLaborTaxMnyCost() {
        return laborTaxMnyCost;
    }

    public void setLaborTaxMnyCost(BigDecimal laborTaxMnyCost) {
        this.laborTaxMnyCost = laborTaxMnyCost;
    }

    public BigDecimal getMajorTaxMnyCost() {
        return majorTaxMnyCost;
    }

    public void setMajorTaxMnyCost(BigDecimal majorTaxMnyCost) {
        this.majorTaxMnyCost = majorTaxMnyCost;
    }

    public BigDecimal getMaterialTaxMnyCost() {
        return materialTaxMnyCost;
    }

    public void setMaterialTaxMnyCost(BigDecimal materialTaxMnyCost) {
        this.materialTaxMnyCost = materialTaxMnyCost;
    }

    public BigDecimal getMechanicalTaxMnyCost() {
        return mechanicalTaxMnyCost;
    }

    public void setMechanicalTaxMnyCost(BigDecimal mechanicalTaxMnyCost) {
        this.mechanicalTaxMnyCost = mechanicalTaxMnyCost;
    }

    public BigDecimal getIndirectionTaxMnyCost() {
        return indirectionTaxMnyCost;
    }

    public void setIndirectionTaxMnyCost(BigDecimal indirectionTaxMnyCost) {
        this.indirectionTaxMnyCost = indirectionTaxMnyCost;
    }

    public List<CostStatisticDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<CostStatisticDetailVO> detailList) {
        this.detailList = detailList;
    }

    public BigDecimal getLastTaxMnyCostRatio() {
        return lastTaxMnyCostRatio;
    }

    public void setLastTaxMnyCostRatio(BigDecimal lastTaxMnyCostRatio) {
        this.lastTaxMnyCostRatio = lastTaxMnyCostRatio;
    }

    public BigDecimal getLaborTaxMnyCostRatio() {
        return laborTaxMnyCostRatio;
    }

    public void setLaborTaxMnyCostRatio(BigDecimal laborTaxMnyCostRatio) {
        this.laborTaxMnyCostRatio = laborTaxMnyCostRatio;
    }

    public BigDecimal getMajorTaxMnyCostRatio() {
        return majorTaxMnyCostRatio;
    }

    public void setMajorTaxMnyCostRatio(BigDecimal majorTaxMnyCostRatio) {
        this.majorTaxMnyCostRatio = majorTaxMnyCostRatio;
    }

    public BigDecimal getMaterialTaxMnyCostRatio() {
        return materialTaxMnyCostRatio;
    }

    public void setMaterialTaxMnyCostRatio(BigDecimal materialTaxMnyCostRatio) {
        this.materialTaxMnyCostRatio = materialTaxMnyCostRatio;
    }

    public BigDecimal getMechanicalTaxMnyCostRatio() {
        return mechanicalTaxMnyCostRatio;
    }

    public void setMechanicalTaxMnyCostRatio(BigDecimal mechanicalTaxMnyCostRatio) {
        this.mechanicalTaxMnyCostRatio = mechanicalTaxMnyCostRatio;
    }

    public BigDecimal getIndirectionTaxMnyCostRatio() {
        return indirectionTaxMnyCostRatio;
    }

    public void setIndirectionTaxMnyCostRatio(BigDecimal indirectionTaxMnyCostRatio) {
        this.indirectionTaxMnyCostRatio = indirectionTaxMnyCostRatio;
    }
}
